@@ -7,9 +7,9 @@ templates_path = ['_templates']
 source_suffix = '.rst'
 master_doc = 'index'
 project = u'webcolors'
-copyright = u'2009-2014, James Bennett'
-version = '1.5'
-release = '1.5'
+copyright = u'2008-2018, James Bennett'
+version = '1.8'
+release = '1.8.1'
 exclude_trees = ['_build']
 pygments_style = 'sphinx'
 html_static_path = ['_static']
@@ -22,4 +22,3 @@ if not on_rtd:
     import sphinx_rtd_theme
     html_theme = 'sphinx_rtd_theme'
     html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
-
